# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='auth.proto',
  package='org.couchers.auth',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nauth.proto\x12\x11org.couchers.auth\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x9d\x02\n\rSignupFlowReq\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12-\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\x1e.org.couchers.auth.SignupBasic\x12\x31\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32 .org.couchers.auth.SignupAccount\x12\x34\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\x12\x19\n\x0b\x65mail_token\x18\x05 \x01(\tB\x04\x80\xb5\x18\x01\x12?\n\x1b\x61\x63\x63\x65pt_community_guidelines\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xdd\x01\n\rSignupFlowRes\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12,\n\x08\x61uth_res\x18\x03 \x01(\x0b\x32\x1a.org.couchers.auth.AuthRes\x12\x12\n\nneed_basic\x18\x04 \x01(\x08\x12\x14\n\x0cneed_account\x18\x05 \x01(\x08\x12\x15\n\rneed_feedback\x18\x06 \x01(\x08\x12\x19\n\x11need_verify_email\x18\x07 \x01(\x08\x12(\n need_accept_community_guidelines\x18\x08 \x01(\x08\"*\n\x0bSignupBasic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"0\n\x12SignupTokenInfoReq\x12\x1a\n\x0csignup_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"\xe6\x01\n\rSignupAccount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\x01\x12\x0b\n\x03lng\x18\x08 \x01(\x01\x12\x0e\n\x06radius\x18\t \x01(\x01\x12\x11\n\tbirthdate\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12<\n\x0ehosting_status\x18\x05 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12\x12\n\naccept_tos\x18\n \x01(\x08\"$\n\x10UsernameValidReq\x12\x10\n\x08username\x18\x01 \x01(\t\"!\n\x10UsernameValidRes\x12\r\n\x05valid\x18\x01 \x01(\x08\"\x18\n\x08LoginReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"z\n\x08LoginRes\x12\x38\n\tnext_step\x18\x01 \x01(\x0e\x32%.org.couchers.auth.LoginRes.LoginStep\"4\n\tLoginStep\x12\x11\n\rNEED_PASSWORD\x10\x00\x12\x14\n\x10SENT_LOGIN_EMAIL\x10\x01\"2\n\x15\x43ompleteTokenLoginReq\x12\x19\n\x0blogin_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"H\n\x07\x41uthReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x17\n\x0fremember_device\x18\x03 \x01(\x08\"*\n\x07\x41uthRes\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0e\n\x06jailed\x18\x02 \x01(\x08\" \n\x10ResetPasswordReq\x12\x0c\n\x04user\x18\x01 \x01(\t\">\n\x18\x43ompletePasswordResetReq\x12\"\n\x14password_reset_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"9\n\x15\x43onfirmChangeEmailReq\x12 \n\x12\x63hange_email_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"Q\n\x15\x43onfirmChangeEmailRes\x12\x38\n\x05state\x18\x01 \x01(\x0e\x32).org.couchers.auth.EmailConfirmationState\"\xab\x01\n\x0f\x43ontributorForm\x12\r\n\x05ideas\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x02 \x01(\t\x12\x12\n\nexperience\x18\x03 \x01(\t\x12\x37\n\ncontribute\x18\x04 \x01(\x0e\x32#.org.couchers.auth.ContributeOption\x12\x17\n\x0f\x63ontribute_ways\x18\x05 \x03(\t\x12\x11\n\texpertise\x18\x06 \x01(\t*\xea\x01\n\x16\x45mailConfirmationState\x12$\n EMAIL_CONFIRMATION_STATE_UNKNOWN\x10\x00\x12$\n EMAIL_CONFIRMATION_STATE_SUCCESS\x10\x01\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL\x10\x02\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL\x10\x03*\x87\x01\n\x10\x43ontributeOption\x12!\n\x1d\x43ONTRIBUTE_OPTION_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43ONTRIBUTE_OPTION_YES\x10\x01\x12\x1b\n\x17\x43ONTRIBUTE_OPTION_MAYBE\x10\x02\x12\x18\n\x14\x43ONTRIBUTE_OPTION_NO\x10\x03\x32\xa1\x06\n\x04\x41uth\x12i\n\nSignupFlow\x12 .org.couchers.auth.SignupFlowReq\x1a .org.couchers.auth.SignupFlowRes\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/auth/signup:\x01*\x12[\n\rUsernameValid\x12#.org.couchers.auth.UsernameValidReq\x1a#.org.couchers.auth.UsernameValidRes\"\x00\x12\x43\n\x05Login\x12\x1b.org.couchers.auth.LoginReq\x1a\x1b.org.couchers.auth.LoginRes\"\x00\x12\\\n\x12\x43ompleteTokenLogin\x12(.org.couchers.auth.CompleteTokenLoginReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12H\n\x0c\x41uthenticate\x12\x1a.org.couchers.auth.AuthReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12\x42\n\x0e\x44\x65\x61uthenticate\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\rResetPassword\x12#.org.couchers.auth.ResetPasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12^\n\x15\x43ompletePasswordReset\x12+.org.couchers.auth.CompletePasswordResetReq\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x12\x43onfirmChangeEmail\x12(.org.couchers.auth.ConfirmChangeEmailReq\x1a(.org.couchers.auth.ConfirmChangeEmailRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,api__pb2.DESCRIPTOR,])

_EMAILCONFIRMATIONSTATE = _descriptor.EnumDescriptor(
  name='EmailConfirmationState',
  full_name='org.couchers.auth.EmailConfirmationState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_SUCCESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1801,
  serialized_end=2035,
)
_sym_db.RegisterEnumDescriptor(_EMAILCONFIRMATIONSTATE)

EmailConfirmationState = enum_type_wrapper.EnumTypeWrapper(_EMAILCONFIRMATIONSTATE)
_CONTRIBUTEOPTION = _descriptor.EnumDescriptor(
  name='ContributeOption',
  full_name='org.couchers.auth.ContributeOption',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTRIBUTE_OPTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTRIBUTE_OPTION_YES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTRIBUTE_OPTION_MAYBE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTRIBUTE_OPTION_NO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2038,
  serialized_end=2173,
)
_sym_db.RegisterEnumDescriptor(_CONTRIBUTEOPTION)

ContributeOption = enum_type_wrapper.EnumTypeWrapper(_CONTRIBUTEOPTION)
EMAIL_CONFIRMATION_STATE_UNKNOWN = 0
EMAIL_CONFIRMATION_STATE_SUCCESS = 1
EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL = 2
EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL = 3
CONTRIBUTE_OPTION_UNSPECIFIED = 0
CONTRIBUTE_OPTION_YES = 1
CONTRIBUTE_OPTION_MAYBE = 2
CONTRIBUTE_OPTION_NO = 3


_LOGINRES_LOGINSTEP = _descriptor.EnumDescriptor(
  name='LoginStep',
  full_name='org.couchers.auth.LoginRes.LoginStep',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEED_PASSWORD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENT_LOGIN_EMAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1162,
  serialized_end=1214,
)
_sym_db.RegisterEnumDescriptor(_LOGINRES_LOGINSTEP)


_SIGNUPFLOWREQ = _descriptor.Descriptor(
  name='SignupFlowReq',
  full_name='org.couchers.auth.SignupFlowReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_token', full_name='org.couchers.auth.SignupFlowReq.flow_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basic', full_name='org.couchers.auth.SignupFlowReq.basic', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='org.couchers.auth.SignupFlowReq.account', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback', full_name='org.couchers.auth.SignupFlowReq.feedback', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_token', full_name='org.couchers.auth.SignupFlowReq.email_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept_community_guidelines', full_name='org.couchers.auth.SignupFlowReq.accept_community_guidelines', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=440,
)


_SIGNUPFLOWRES = _descriptor.Descriptor(
  name='SignupFlowRes',
  full_name='org.couchers.auth.SignupFlowRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_token', full_name='org.couchers.auth.SignupFlowRes.flow_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_res', full_name='org.couchers.auth.SignupFlowRes.auth_res', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_basic', full_name='org.couchers.auth.SignupFlowRes.need_basic', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_account', full_name='org.couchers.auth.SignupFlowRes.need_account', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_feedback', full_name='org.couchers.auth.SignupFlowRes.need_feedback', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_verify_email', full_name='org.couchers.auth.SignupFlowRes.need_verify_email', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_accept_community_guidelines', full_name='org.couchers.auth.SignupFlowRes.need_accept_community_guidelines', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=664,
)


_SIGNUPBASIC = _descriptor.Descriptor(
  name='SignupBasic',
  full_name='org.couchers.auth.SignupBasic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.auth.SignupBasic.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='org.couchers.auth.SignupBasic.email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=708,
)


_SIGNUPTOKENINFOREQ = _descriptor.Descriptor(
  name='SignupTokenInfoReq',
  full_name='org.couchers.auth.SignupTokenInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signup_token', full_name='org.couchers.auth.SignupTokenInfoReq.signup_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=758,
)


_SIGNUPACCOUNT = _descriptor.Descriptor(
  name='SignupAccount',
  full_name='org.couchers.auth.SignupAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.auth.SignupAccount.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='org.couchers.auth.SignupAccount.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='org.couchers.auth.SignupAccount.city', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.auth.SignupAccount.lat', index=3,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.auth.SignupAccount.lng', index=4,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='org.couchers.auth.SignupAccount.radius', index=5,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='birthdate', full_name='org.couchers.auth.SignupAccount.birthdate', index=6,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.auth.SignupAccount.gender', index=7,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosting_status', full_name='org.couchers.auth.SignupAccount.hosting_status', index=8,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept_tos', full_name='org.couchers.auth.SignupAccount.accept_tos', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=991,
)


_USERNAMEVALIDREQ = _descriptor.Descriptor(
  name='UsernameValidReq',
  full_name='org.couchers.auth.UsernameValidReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.auth.UsernameValidReq.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1029,
)


_USERNAMEVALIDRES = _descriptor.Descriptor(
  name='UsernameValidRes',
  full_name='org.couchers.auth.UsernameValidRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='org.couchers.auth.UsernameValidRes.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1064,
)


_LOGINREQ = _descriptor.Descriptor(
  name='LoginReq',
  full_name='org.couchers.auth.LoginReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.LoginReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1090,
)


_LOGINRES = _descriptor.Descriptor(
  name='LoginRes',
  full_name='org.couchers.auth.LoginRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_step', full_name='org.couchers.auth.LoginRes.next_step', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGINRES_LOGINSTEP,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1214,
)


_COMPLETETOKENLOGINREQ = _descriptor.Descriptor(
  name='CompleteTokenLoginReq',
  full_name='org.couchers.auth.CompleteTokenLoginReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='login_token', full_name='org.couchers.auth.CompleteTokenLoginReq.login_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1216,
  serialized_end=1266,
)


_AUTHREQ = _descriptor.Descriptor(
  name='AuthReq',
  full_name='org.couchers.auth.AuthReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.AuthReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='org.couchers.auth.AuthReq.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remember_device', full_name='org.couchers.auth.AuthReq.remember_device', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1268,
  serialized_end=1340,
)


_AUTHRES = _descriptor.Descriptor(
  name='AuthRes',
  full_name='org.couchers.auth.AuthRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.auth.AuthRes.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jailed', full_name='org.couchers.auth.AuthRes.jailed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1384,
)


_RESETPASSWORDREQ = _descriptor.Descriptor(
  name='ResetPasswordReq',
  full_name='org.couchers.auth.ResetPasswordReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.ResetPasswordReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1418,
)


_COMPLETEPASSWORDRESETREQ = _descriptor.Descriptor(
  name='CompletePasswordResetReq',
  full_name='org.couchers.auth.CompletePasswordResetReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password_reset_token', full_name='org.couchers.auth.CompletePasswordResetReq.password_reset_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1420,
  serialized_end=1482,
)


_CONFIRMCHANGEEMAILREQ = _descriptor.Descriptor(
  name='ConfirmChangeEmailReq',
  full_name='org.couchers.auth.ConfirmChangeEmailReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_email_token', full_name='org.couchers.auth.ConfirmChangeEmailReq.change_email_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1484,
  serialized_end=1541,
)


_CONFIRMCHANGEEMAILRES = _descriptor.Descriptor(
  name='ConfirmChangeEmailRes',
  full_name='org.couchers.auth.ConfirmChangeEmailRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='org.couchers.auth.ConfirmChangeEmailRes.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1543,
  serialized_end=1624,
)


_CONTRIBUTORFORM = _descriptor.Descriptor(
  name='ContributorForm',
  full_name='org.couchers.auth.ContributorForm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ideas', full_name='org.couchers.auth.ContributorForm.ideas', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='org.couchers.auth.ContributorForm.features', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experience', full_name='org.couchers.auth.ContributorForm.experience', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contribute', full_name='org.couchers.auth.ContributorForm.contribute', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contribute_ways', full_name='org.couchers.auth.ContributorForm.contribute_ways', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expertise', full_name='org.couchers.auth.ContributorForm.expertise', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1627,
  serialized_end=1798,
)

_SIGNUPFLOWREQ.fields_by_name['basic'].message_type = _SIGNUPBASIC
_SIGNUPFLOWREQ.fields_by_name['account'].message_type = _SIGNUPACCOUNT
_SIGNUPFLOWREQ.fields_by_name['feedback'].message_type = _CONTRIBUTORFORM
_SIGNUPFLOWREQ.fields_by_name['accept_community_guidelines'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SIGNUPFLOWRES.fields_by_name['auth_res'].message_type = _AUTHRES
_SIGNUPACCOUNT.fields_by_name['hosting_status'].enum_type = api__pb2._HOSTINGSTATUS
_LOGINRES.fields_by_name['next_step'].enum_type = _LOGINRES_LOGINSTEP
_LOGINRES_LOGINSTEP.containing_type = _LOGINRES
_CONFIRMCHANGEEMAILRES.fields_by_name['state'].enum_type = _EMAILCONFIRMATIONSTATE
_CONTRIBUTORFORM.fields_by_name['contribute'].enum_type = _CONTRIBUTEOPTION
DESCRIPTOR.message_types_by_name['SignupFlowReq'] = _SIGNUPFLOWREQ
DESCRIPTOR.message_types_by_name['SignupFlowRes'] = _SIGNUPFLOWRES
DESCRIPTOR.message_types_by_name['SignupBasic'] = _SIGNUPBASIC
DESCRIPTOR.message_types_by_name['SignupTokenInfoReq'] = _SIGNUPTOKENINFOREQ
DESCRIPTOR.message_types_by_name['SignupAccount'] = _SIGNUPACCOUNT
DESCRIPTOR.message_types_by_name['UsernameValidReq'] = _USERNAMEVALIDREQ
DESCRIPTOR.message_types_by_name['UsernameValidRes'] = _USERNAMEVALIDRES
DESCRIPTOR.message_types_by_name['LoginReq'] = _LOGINREQ
DESCRIPTOR.message_types_by_name['LoginRes'] = _LOGINRES
DESCRIPTOR.message_types_by_name['CompleteTokenLoginReq'] = _COMPLETETOKENLOGINREQ
DESCRIPTOR.message_types_by_name['AuthReq'] = _AUTHREQ
DESCRIPTOR.message_types_by_name['AuthRes'] = _AUTHRES
DESCRIPTOR.message_types_by_name['ResetPasswordReq'] = _RESETPASSWORDREQ
DESCRIPTOR.message_types_by_name['CompletePasswordResetReq'] = _COMPLETEPASSWORDRESETREQ
DESCRIPTOR.message_types_by_name['ConfirmChangeEmailReq'] = _CONFIRMCHANGEEMAILREQ
DESCRIPTOR.message_types_by_name['ConfirmChangeEmailRes'] = _CONFIRMCHANGEEMAILRES
DESCRIPTOR.message_types_by_name['ContributorForm'] = _CONTRIBUTORFORM
DESCRIPTOR.enum_types_by_name['EmailConfirmationState'] = _EMAILCONFIRMATIONSTATE
DESCRIPTOR.enum_types_by_name['ContributeOption'] = _CONTRIBUTEOPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignupFlowReq = _reflection.GeneratedProtocolMessageType('SignupFlowReq', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPFLOWREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupFlowReq)
  })
_sym_db.RegisterMessage(SignupFlowReq)

SignupFlowRes = _reflection.GeneratedProtocolMessageType('SignupFlowRes', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPFLOWRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupFlowRes)
  })
_sym_db.RegisterMessage(SignupFlowRes)

SignupBasic = _reflection.GeneratedProtocolMessageType('SignupBasic', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPBASIC,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupBasic)
  })
_sym_db.RegisterMessage(SignupBasic)

SignupTokenInfoReq = _reflection.GeneratedProtocolMessageType('SignupTokenInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPTOKENINFOREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupTokenInfoReq)
  })
_sym_db.RegisterMessage(SignupTokenInfoReq)

SignupAccount = _reflection.GeneratedProtocolMessageType('SignupAccount', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPACCOUNT,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupAccount)
  })
_sym_db.RegisterMessage(SignupAccount)

UsernameValidReq = _reflection.GeneratedProtocolMessageType('UsernameValidReq', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEVALIDREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.UsernameValidReq)
  })
_sym_db.RegisterMessage(UsernameValidReq)

UsernameValidRes = _reflection.GeneratedProtocolMessageType('UsernameValidRes', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEVALIDRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.UsernameValidRes)
  })
_sym_db.RegisterMessage(UsernameValidRes)

LoginReq = _reflection.GeneratedProtocolMessageType('LoginReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.LoginReq)
  })
_sym_db.RegisterMessage(LoginReq)

LoginRes = _reflection.GeneratedProtocolMessageType('LoginRes', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.LoginRes)
  })
_sym_db.RegisterMessage(LoginRes)

CompleteTokenLoginReq = _reflection.GeneratedProtocolMessageType('CompleteTokenLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETETOKENLOGINREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.CompleteTokenLoginReq)
  })
_sym_db.RegisterMessage(CompleteTokenLoginReq)

AuthReq = _reflection.GeneratedProtocolMessageType('AuthReq', (_message.Message,), {
  'DESCRIPTOR' : _AUTHREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.AuthReq)
  })
_sym_db.RegisterMessage(AuthReq)

AuthRes = _reflection.GeneratedProtocolMessageType('AuthRes', (_message.Message,), {
  'DESCRIPTOR' : _AUTHRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.AuthRes)
  })
_sym_db.RegisterMessage(AuthRes)

ResetPasswordReq = _reflection.GeneratedProtocolMessageType('ResetPasswordReq', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ResetPasswordReq)
  })
_sym_db.RegisterMessage(ResetPasswordReq)

CompletePasswordResetReq = _reflection.GeneratedProtocolMessageType('CompletePasswordResetReq', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEPASSWORDRESETREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.CompletePasswordResetReq)
  })
_sym_db.RegisterMessage(CompletePasswordResetReq)

ConfirmChangeEmailReq = _reflection.GeneratedProtocolMessageType('ConfirmChangeEmailReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMCHANGEEMAILREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ConfirmChangeEmailReq)
  })
_sym_db.RegisterMessage(ConfirmChangeEmailReq)

ConfirmChangeEmailRes = _reflection.GeneratedProtocolMessageType('ConfirmChangeEmailRes', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMCHANGEEMAILRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ConfirmChangeEmailRes)
  })
_sym_db.RegisterMessage(ConfirmChangeEmailRes)

ContributorForm = _reflection.GeneratedProtocolMessageType('ContributorForm', (_message.Message,), {
  'DESCRIPTOR' : _CONTRIBUTORFORM,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ContributorForm)
  })
_sym_db.RegisterMessage(ContributorForm)


_SIGNUPFLOWREQ.fields_by_name['flow_token']._options = None
_SIGNUPFLOWREQ.fields_by_name['email_token']._options = None
_SIGNUPFLOWRES.fields_by_name['flow_token']._options = None
_SIGNUPTOKENINFOREQ.fields_by_name['signup_token']._options = None
_SIGNUPACCOUNT.fields_by_name['password']._options = None
_COMPLETETOKENLOGINREQ.fields_by_name['login_token']._options = None
_AUTHREQ.fields_by_name['password']._options = None
_COMPLETEPASSWORDRESETREQ.fields_by_name['password_reset_token']._options = None
_CONFIRMCHANGEEMAILREQ.fields_by_name['change_email_token']._options = None

_AUTH = _descriptor.ServiceDescriptor(
  name='Auth',
  full_name='org.couchers.auth.Auth',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\001',
  create_key=_descriptor._internal_create_key,
  serialized_start=2176,
  serialized_end=2977,
  methods=[
  _descriptor.MethodDescriptor(
    name='SignupFlow',
    full_name='org.couchers.auth.Auth.SignupFlow',
    index=0,
    containing_service=None,
    input_type=_SIGNUPFLOWREQ,
    output_type=_SIGNUPFLOWRES,
    serialized_options=b'\202\323\344\223\002\021\"\014/auth/signup:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UsernameValid',
    full_name='org.couchers.auth.Auth.UsernameValid',
    index=1,
    containing_service=None,
    input_type=_USERNAMEVALIDREQ,
    output_type=_USERNAMEVALIDRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='org.couchers.auth.Auth.Login',
    index=2,
    containing_service=None,
    input_type=_LOGINREQ,
    output_type=_LOGINRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteTokenLogin',
    full_name='org.couchers.auth.Auth.CompleteTokenLogin',
    index=3,
    containing_service=None,
    input_type=_COMPLETETOKENLOGINREQ,
    output_type=_AUTHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Authenticate',
    full_name='org.couchers.auth.Auth.Authenticate',
    index=4,
    containing_service=None,
    input_type=_AUTHREQ,
    output_type=_AUTHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Deauthenticate',
    full_name='org.couchers.auth.Auth.Deauthenticate',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetPassword',
    full_name='org.couchers.auth.Auth.ResetPassword',
    index=6,
    containing_service=None,
    input_type=_RESETPASSWORDREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompletePasswordReset',
    full_name='org.couchers.auth.Auth.CompletePasswordReset',
    index=7,
    containing_service=None,
    input_type=_COMPLETEPASSWORDRESETREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfirmChangeEmail',
    full_name='org.couchers.auth.Auth.ConfirmChangeEmail',
    index=8,
    containing_service=None,
    input_type=_CONFIRMCHANGEEMAILREQ,
    output_type=_CONFIRMCHANGEEMAILRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTH)

DESCRIPTOR.services_by_name['Auth'] = _AUTH

# @@protoc_insertion_point(module_scope)
