# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: requests.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import conversations_pb2 as conversations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='requests.proto',
  package='org.couchers.api.requests',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0erequests.proto\x12\x19org.couchers.api.requests\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x13\x63onversations.proto\"^\n\x14\x43reateHostRequestReq\x12\x14\n\x0chost_user_id\x18\x01 \x01(\x03\x12\x11\n\tfrom_date\x18\x02 \x01(\t\x12\x0f\n\x07to_date\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\"\xc7\x02\n\x0bHostRequest\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x16\n\x0esurfer_user_id\x18\x02 \x01(\x03\x12\x14\n\x0chost_user_id\x18\x03 \x01(\x03\x12\x41\n\x06status\x18\x04 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tfrom_date\x18\x06 \x01(\t\x12\x0f\n\x07to_date\x18\x07 \x01(\t\x12\x1c\n\x14last_seen_message_id\x18\x08 \x01(\x03\x12?\n\x0elatest_message\x18\t \x01(\x0b\x32\'.org.couchers.api.conversations.Message\",\n\x11GetHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\"/\n\x14\x43reateHostRequestRes\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\"\x81\x01\n\x15RespondHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\x12\x0c\n\x04text\x18\x03 \x01(\t\"}\n\x13ListHostRequestsReq\x12\x17\n\x0flast_request_id\x18\x01 \x01(\x03\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x13\n\x0bonly_active\x18\x03 \x01(\x08\x12\x11\n\tonly_sent\x18\x04 \x01(\x08\x12\x15\n\ronly_received\x18\x05 \x01(\x08\"~\n\x13ListHostRequestsRes\x12=\n\rhost_requests\x18\x01 \x03(\x0b\x32&.org.couchers.api.requests.HostRequest\x12\x17\n\x0flast_request_id\x18\x02 \x01(\x03\x12\x0f\n\x07no_more\x18\x03 \x01(\x08\"]\n\x19GetHostRequestMessagesReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x03\x12\x0e\n\x06number\x18\x03 \x01(\r\"\x80\x01\n\x19GetHostRequestMessagesRes\x12\x39\n\x08messages\x18\x01 \x03(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x17\n\x0flast_message_id\x18\x04 \x01(\x03\x12\x0f\n\x07no_more\x18\x05 \x01(\x08\"B\n\x19SendHostRequestMessageReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\"o\n\x18GetHostRequestUpdatesReq\x12\x19\n\x11newest_message_id\x18\x01 \x01(\x03\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x11\n\tonly_sent\x18\x03 \x01(\x08\x12\x15\n\ronly_received\x18\x04 \x01(\x08\"\xa9\x01\n\x11HostRequestUpdate\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x38\n\x07message\x18\x02 \x01(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\"j\n\x18GetHostRequestUpdatesRes\x12=\n\x07updates\x18\x01 \x03(\x0b\x32,.org.couchers.api.requests.HostRequestUpdate\x12\x0f\n\x07no_more\x18\x02 \x01(\x08\"S\n\x1aMarkLastSeenHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x1c\n\x14last_seen_message_id\x18\x02 \x01(\x03\x32\xa0\x07\n\x08Requests\x12u\n\x11\x43reateHostRequest\x12/.org.couchers.api.requests.CreateHostRequestReq\x1a/.org.couchers.api.requests.CreateHostRequestRes\x12\x66\n\x0eGetHostRequest\x12,.org.couchers.api.requests.GetHostRequestReq\x1a&.org.couchers.api.requests.HostRequest\x12^\n\x12RespondHostRequest\x12\x30.org.couchers.api.requests.RespondHostRequestReq\x1a\x16.google.protobuf.Empty\x12r\n\x10ListHostRequests\x12..org.couchers.api.requests.ListHostRequestsReq\x1a..org.couchers.api.requests.ListHostRequestsRes\x12\x84\x01\n\x16GetHostRequestMessages\x12\x34.org.couchers.api.requests.GetHostRequestMessagesReq\x1a\x34.org.couchers.api.requests.GetHostRequestMessagesRes\x12\x66\n\x16SendHostRequestMessage\x12\x34.org.couchers.api.requests.SendHostRequestMessageReq\x1a\x16.google.protobuf.Empty\x12\x81\x01\n\x15GetHostRequestUpdates\x12\x33.org.couchers.api.requests.GetHostRequestUpdatesReq\x1a\x33.org.couchers.api.requests.GetHostRequestUpdatesRes\x12h\n\x17MarkLastSeenHostRequest\x12\x35.org.couchers.api.requests.MarkLastSeenHostRequestReq\x1a\x16.google.protobuf.Empty\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,conversations__pb2.DESCRIPTOR,])




_CREATEHOSTREQUESTREQ = _descriptor.Descriptor(
  name='CreateHostRequestReq',
  full_name='org.couchers.api.requests.CreateHostRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_user_id', full_name='org.couchers.api.requests.CreateHostRequestReq.host_user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_date', full_name='org.couchers.api.requests.CreateHostRequestReq.from_date', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='org.couchers.api.requests.CreateHostRequestReq.to_date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.requests.CreateHostRequestReq.text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=241,
)


_HOSTREQUEST = _descriptor.Descriptor(
  name='HostRequest',
  full_name='org.couchers.api.requests.HostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.HostRequest.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='surfer_user_id', full_name='org.couchers.api.requests.HostRequest.surfer_user_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_user_id', full_name='org.couchers.api.requests.HostRequest.host_user_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='org.couchers.api.requests.HostRequest.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='org.couchers.api.requests.HostRequest.created', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_date', full_name='org.couchers.api.requests.HostRequest.from_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='org.couchers.api.requests.HostRequest.to_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_seen_message_id', full_name='org.couchers.api.requests.HostRequest.last_seen_message_id', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_message', full_name='org.couchers.api.requests.HostRequest.latest_message', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=571,
)


_GETHOSTREQUESTREQ = _descriptor.Descriptor(
  name='GetHostRequestReq',
  full_name='org.couchers.api.requests.GetHostRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.GetHostRequestReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=617,
)


_CREATEHOSTREQUESTRES = _descriptor.Descriptor(
  name='CreateHostRequestRes',
  full_name='org.couchers.api.requests.CreateHostRequestRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.CreateHostRequestRes.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=666,
)


_RESPONDHOSTREQUESTREQ = _descriptor.Descriptor(
  name='RespondHostRequestReq',
  full_name='org.couchers.api.requests.RespondHostRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.RespondHostRequestReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='org.couchers.api.requests.RespondHostRequestReq.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.requests.RespondHostRequestReq.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=798,
)


_LISTHOSTREQUESTSREQ = _descriptor.Descriptor(
  name='ListHostRequestsReq',
  full_name='org.couchers.api.requests.ListHostRequestsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_request_id', full_name='org.couchers.api.requests.ListHostRequestsReq.last_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='org.couchers.api.requests.ListHostRequestsReq.number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_active', full_name='org.couchers.api.requests.ListHostRequestsReq.only_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_sent', full_name='org.couchers.api.requests.ListHostRequestsReq.only_sent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_received', full_name='org.couchers.api.requests.ListHostRequestsReq.only_received', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=925,
)


_LISTHOSTREQUESTSRES = _descriptor.Descriptor(
  name='ListHostRequestsRes',
  full_name='org.couchers.api.requests.ListHostRequestsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_requests', full_name='org.couchers.api.requests.ListHostRequestsRes.host_requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_request_id', full_name='org.couchers.api.requests.ListHostRequestsRes.last_request_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_more', full_name='org.couchers.api.requests.ListHostRequestsRes.no_more', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=1053,
)


_GETHOSTREQUESTMESSAGESREQ = _descriptor.Descriptor(
  name='GetHostRequestMessagesReq',
  full_name='org.couchers.api.requests.GetHostRequestMessagesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.GetHostRequestMessagesReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_message_id', full_name='org.couchers.api.requests.GetHostRequestMessagesReq.last_message_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='org.couchers.api.requests.GetHostRequestMessagesReq.number', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1055,
  serialized_end=1148,
)


_GETHOSTREQUESTMESSAGESRES = _descriptor.Descriptor(
  name='GetHostRequestMessagesRes',
  full_name='org.couchers.api.requests.GetHostRequestMessagesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='org.couchers.api.requests.GetHostRequestMessagesRes.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_message_id', full_name='org.couchers.api.requests.GetHostRequestMessagesRes.last_message_id', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_more', full_name='org.couchers.api.requests.GetHostRequestMessagesRes.no_more', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1279,
)


_SENDHOSTREQUESTMESSAGEREQ = _descriptor.Descriptor(
  name='SendHostRequestMessageReq',
  full_name='org.couchers.api.requests.SendHostRequestMessageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.SendHostRequestMessageReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.requests.SendHostRequestMessageReq.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1347,
)


_GETHOSTREQUESTUPDATESREQ = _descriptor.Descriptor(
  name='GetHostRequestUpdatesReq',
  full_name='org.couchers.api.requests.GetHostRequestUpdatesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='newest_message_id', full_name='org.couchers.api.requests.GetHostRequestUpdatesReq.newest_message_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='org.couchers.api.requests.GetHostRequestUpdatesReq.number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_sent', full_name='org.couchers.api.requests.GetHostRequestUpdatesReq.only_sent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_received', full_name='org.couchers.api.requests.GetHostRequestUpdatesReq.only_received', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1349,
  serialized_end=1460,
)


_HOSTREQUESTUPDATE = _descriptor.Descriptor(
  name='HostRequestUpdate',
  full_name='org.couchers.api.requests.HostRequestUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.HostRequestUpdate.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='org.couchers.api.requests.HostRequestUpdate.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='org.couchers.api.requests.HostRequestUpdate.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1632,
)


_GETHOSTREQUESTUPDATESRES = _descriptor.Descriptor(
  name='GetHostRequestUpdatesRes',
  full_name='org.couchers.api.requests.GetHostRequestUpdatesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='updates', full_name='org.couchers.api.requests.GetHostRequestUpdatesRes.updates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_more', full_name='org.couchers.api.requests.GetHostRequestUpdatesRes.no_more', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1634,
  serialized_end=1740,
)


_MARKLASTSEENHOSTREQUESTREQ = _descriptor.Descriptor(
  name='MarkLastSeenHostRequestReq',
  full_name='org.couchers.api.requests.MarkLastSeenHostRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.MarkLastSeenHostRequestReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_seen_message_id', full_name='org.couchers.api.requests.MarkLastSeenHostRequestReq.last_seen_message_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1825,
)

_HOSTREQUEST.fields_by_name['status'].enum_type = conversations__pb2._HOSTREQUESTSTATUS
_HOSTREQUEST.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HOSTREQUEST.fields_by_name['latest_message'].message_type = conversations__pb2._MESSAGE
_RESPONDHOSTREQUESTREQ.fields_by_name['status'].enum_type = conversations__pb2._HOSTREQUESTSTATUS
_LISTHOSTREQUESTSRES.fields_by_name['host_requests'].message_type = _HOSTREQUEST
_GETHOSTREQUESTMESSAGESRES.fields_by_name['messages'].message_type = conversations__pb2._MESSAGE
_HOSTREQUESTUPDATE.fields_by_name['message'].message_type = conversations__pb2._MESSAGE
_HOSTREQUESTUPDATE.fields_by_name['status'].enum_type = conversations__pb2._HOSTREQUESTSTATUS
_GETHOSTREQUESTUPDATESRES.fields_by_name['updates'].message_type = _HOSTREQUESTUPDATE
DESCRIPTOR.message_types_by_name['CreateHostRequestReq'] = _CREATEHOSTREQUESTREQ
DESCRIPTOR.message_types_by_name['HostRequest'] = _HOSTREQUEST
DESCRIPTOR.message_types_by_name['GetHostRequestReq'] = _GETHOSTREQUESTREQ
DESCRIPTOR.message_types_by_name['CreateHostRequestRes'] = _CREATEHOSTREQUESTRES
DESCRIPTOR.message_types_by_name['RespondHostRequestReq'] = _RESPONDHOSTREQUESTREQ
DESCRIPTOR.message_types_by_name['ListHostRequestsReq'] = _LISTHOSTREQUESTSREQ
DESCRIPTOR.message_types_by_name['ListHostRequestsRes'] = _LISTHOSTREQUESTSRES
DESCRIPTOR.message_types_by_name['GetHostRequestMessagesReq'] = _GETHOSTREQUESTMESSAGESREQ
DESCRIPTOR.message_types_by_name['GetHostRequestMessagesRes'] = _GETHOSTREQUESTMESSAGESRES
DESCRIPTOR.message_types_by_name['SendHostRequestMessageReq'] = _SENDHOSTREQUESTMESSAGEREQ
DESCRIPTOR.message_types_by_name['GetHostRequestUpdatesReq'] = _GETHOSTREQUESTUPDATESREQ
DESCRIPTOR.message_types_by_name['HostRequestUpdate'] = _HOSTREQUESTUPDATE
DESCRIPTOR.message_types_by_name['GetHostRequestUpdatesRes'] = _GETHOSTREQUESTUPDATESRES
DESCRIPTOR.message_types_by_name['MarkLastSeenHostRequestReq'] = _MARKLASTSEENHOSTREQUESTREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateHostRequestReq = _reflection.GeneratedProtocolMessageType('CreateHostRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEHOSTREQUESTREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.CreateHostRequestReq)
  })
_sym_db.RegisterMessage(CreateHostRequestReq)

HostRequest = _reflection.GeneratedProtocolMessageType('HostRequest', (_message.Message,), {
  'DESCRIPTOR' : _HOSTREQUEST,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.HostRequest)
  })
_sym_db.RegisterMessage(HostRequest)

GetHostRequestReq = _reflection.GeneratedProtocolMessageType('GetHostRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestReq)
  })
_sym_db.RegisterMessage(GetHostRequestReq)

CreateHostRequestRes = _reflection.GeneratedProtocolMessageType('CreateHostRequestRes', (_message.Message,), {
  'DESCRIPTOR' : _CREATEHOSTREQUESTRES,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.CreateHostRequestRes)
  })
_sym_db.RegisterMessage(CreateHostRequestRes)

RespondHostRequestReq = _reflection.GeneratedProtocolMessageType('RespondHostRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _RESPONDHOSTREQUESTREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.RespondHostRequestReq)
  })
_sym_db.RegisterMessage(RespondHostRequestReq)

ListHostRequestsReq = _reflection.GeneratedProtocolMessageType('ListHostRequestsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTREQUESTSREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.ListHostRequestsReq)
  })
_sym_db.RegisterMessage(ListHostRequestsReq)

ListHostRequestsRes = _reflection.GeneratedProtocolMessageType('ListHostRequestsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTREQUESTSRES,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.ListHostRequestsRes)
  })
_sym_db.RegisterMessage(ListHostRequestsRes)

GetHostRequestMessagesReq = _reflection.GeneratedProtocolMessageType('GetHostRequestMessagesReq', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTMESSAGESREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestMessagesReq)
  })
_sym_db.RegisterMessage(GetHostRequestMessagesReq)

GetHostRequestMessagesRes = _reflection.GeneratedProtocolMessageType('GetHostRequestMessagesRes', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTMESSAGESRES,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestMessagesRes)
  })
_sym_db.RegisterMessage(GetHostRequestMessagesRes)

SendHostRequestMessageReq = _reflection.GeneratedProtocolMessageType('SendHostRequestMessageReq', (_message.Message,), {
  'DESCRIPTOR' : _SENDHOSTREQUESTMESSAGEREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.SendHostRequestMessageReq)
  })
_sym_db.RegisterMessage(SendHostRequestMessageReq)

GetHostRequestUpdatesReq = _reflection.GeneratedProtocolMessageType('GetHostRequestUpdatesReq', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTUPDATESREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestUpdatesReq)
  })
_sym_db.RegisterMessage(GetHostRequestUpdatesReq)

HostRequestUpdate = _reflection.GeneratedProtocolMessageType('HostRequestUpdate', (_message.Message,), {
  'DESCRIPTOR' : _HOSTREQUESTUPDATE,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.HostRequestUpdate)
  })
_sym_db.RegisterMessage(HostRequestUpdate)

GetHostRequestUpdatesRes = _reflection.GeneratedProtocolMessageType('GetHostRequestUpdatesRes', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTUPDATESRES,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestUpdatesRes)
  })
_sym_db.RegisterMessage(GetHostRequestUpdatesRes)

MarkLastSeenHostRequestReq = _reflection.GeneratedProtocolMessageType('MarkLastSeenHostRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _MARKLASTSEENHOSTREQUESTREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.MarkLastSeenHostRequestReq)
  })
_sym_db.RegisterMessage(MarkLastSeenHostRequestReq)



_REQUESTS = _descriptor.ServiceDescriptor(
  name='Requests',
  full_name='org.couchers.api.requests.Requests',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=1828,
  serialized_end=2756,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateHostRequest',
    full_name='org.couchers.api.requests.Requests.CreateHostRequest',
    index=0,
    containing_service=None,
    input_type=_CREATEHOSTREQUESTREQ,
    output_type=_CREATEHOSTREQUESTRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHostRequest',
    full_name='org.couchers.api.requests.Requests.GetHostRequest',
    index=1,
    containing_service=None,
    input_type=_GETHOSTREQUESTREQ,
    output_type=_HOSTREQUEST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RespondHostRequest',
    full_name='org.couchers.api.requests.Requests.RespondHostRequest',
    index=2,
    containing_service=None,
    input_type=_RESPONDHOSTREQUESTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListHostRequests',
    full_name='org.couchers.api.requests.Requests.ListHostRequests',
    index=3,
    containing_service=None,
    input_type=_LISTHOSTREQUESTSREQ,
    output_type=_LISTHOSTREQUESTSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHostRequestMessages',
    full_name='org.couchers.api.requests.Requests.GetHostRequestMessages',
    index=4,
    containing_service=None,
    input_type=_GETHOSTREQUESTMESSAGESREQ,
    output_type=_GETHOSTREQUESTMESSAGESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendHostRequestMessage',
    full_name='org.couchers.api.requests.Requests.SendHostRequestMessage',
    index=5,
    containing_service=None,
    input_type=_SENDHOSTREQUESTMESSAGEREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHostRequestUpdates',
    full_name='org.couchers.api.requests.Requests.GetHostRequestUpdates',
    index=6,
    containing_service=None,
    input_type=_GETHOSTREQUESTUPDATESREQ,
    output_type=_GETHOSTREQUESTUPDATESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MarkLastSeenHostRequest',
    full_name='org.couchers.api.requests.Requests.MarkLastSeenHostRequest',
    index=7,
    containing_service=None,
    input_type=_MARKLASTSEENHOSTREQUESTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REQUESTS)

DESCRIPTOR.services_by_name['Requests'] = _REQUESTS

# @@protoc_insertion_point(module_scope)
