# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: reporting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='reporting.proto',
  package='org.couchers.api.reporting',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0freporting.proto\x12\x1aorg.couchers.api.reporting\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"|\n\tReportReq\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_ref\x18\x03 \x01(\t\x12\x13\n\x0b\x61uthor_user\x18\x04 \x01(\t\x12\x12\n\nuser_agent\x18\x05 \x01(\t\x12\x0c\n\x04page\x18\x06 \x01(\t2\\\n\tReporting\x12I\n\x06Report\x12%.org.couchers.api.reporting.ReportReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_REPORTREQ = _descriptor.Descriptor(
  name='ReportReq',
  full_name='org.couchers.api.reporting.ReportReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='org.couchers.api.reporting.ReportReq.reason', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.api.reporting.ReportReq.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_ref', full_name='org.couchers.api.reporting.ReportReq.content_ref', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author_user', full_name='org.couchers.api.reporting.ReportReq.author_user', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='org.couchers.api.reporting.ReportReq.user_agent', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page', full_name='org.couchers.api.reporting.ReportReq.page', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=219,
)

DESCRIPTOR.message_types_by_name['ReportReq'] = _REPORTREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReportReq = _reflection.GeneratedProtocolMessageType('ReportReq', (_message.Message,), {
  'DESCRIPTOR' : _REPORTREQ,
  '__module__' : 'reporting_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.reporting.ReportReq)
  })
_sym_db.RegisterMessage(ReportReq)



_REPORTING = _descriptor.ServiceDescriptor(
  name='Reporting',
  full_name='org.couchers.api.reporting.Reporting',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=221,
  serialized_end=313,
  methods=[
  _descriptor.MethodDescriptor(
    name='Report',
    full_name='org.couchers.api.reporting.Reporting.Report',
    index=0,
    containing_service=None,
    input_type=_REPORTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REPORTING)

DESCRIPTOR.services_by_name['Reporting'] = _REPORTING

# @@protoc_insertion_point(module_scope)
