# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: annotations.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='annotations.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x61nnotations.proto\x1a google/protobuf/descriptor.proto*|\n\tAuthLevel\x12\x16\n\x12\x41UTH_LEVEL_UNKNOWN\x10\x00\x12\x13\n\x0f\x41UTH_LEVEL_OPEN\x10\x01\x12\x15\n\x11\x41UTH_LEVEL_JAILED\x10\x02\x12\x15\n\x11\x41UTH_LEVEL_SECURE\x10\x03\x12\x14\n\x10\x41UTH_LEVEL_ADMIN\x10\x04:2\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x08:A\n\nauth_level\x12\x1f.google.protobuf.ServiceOptions\x18\xd1\x86\x03 \x01(\x0e\x32\n.AuthLevelb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_AUTHLEVEL = _descriptor.EnumDescriptor(
  name='AuthLevel',
  full_name='AuthLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_JAILED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_SECURE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_ADMIN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55,
  serialized_end=179,
)
_sym_db.RegisterEnumDescriptor(_AUTHLEVEL)

AuthLevel = enum_type_wrapper.EnumTypeWrapper(_AUTHLEVEL)
AUTH_LEVEL_UNKNOWN = 0
AUTH_LEVEL_OPEN = 1
AUTH_LEVEL_JAILED = 2
AUTH_LEVEL_SECURE = 3
AUTH_LEVEL_ADMIN = 4

SENSITIVE_FIELD_NUMBER = 50000
sensitive = _descriptor.FieldDescriptor(
  name='sensitive', full_name='sensitive', index=0,
  number=50000, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
AUTH_LEVEL_FIELD_NUMBER = 50001
auth_level = _descriptor.FieldDescriptor(
  name='auth_level', full_name='auth_level', index=1,
  number=50001, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

DESCRIPTOR.enum_types_by_name['AuthLevel'] = _AUTHLEVEL
DESCRIPTOR.extensions_by_name['sensitive'] = sensitive
DESCRIPTOR.extensions_by_name['auth_level'] = auth_level
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(sensitive)
auth_level.enum_type = _AUTHLEVEL
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(auth_level)

# @@protoc_insertion_point(module_scope)
