# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jail.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='jail.proto',
  package='org.couchers.jail',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\njail.proto\x12\x11org.couchers.jail\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"\x8a\x01\n\x0bJailInfoRes\x12\x0e\n\x06jailed\x18\x01 \x01(\x08\x12\x1c\n\x14has_not_accepted_tos\x18\x02 \x01(\x08\x12\x1e\n\x16has_not_added_location\x18\x03 \x01(\x08\x12-\n%has_not_accepted_community_guidelines\x18\x04 \x01(\x08\"\x1e\n\x0c\x41\x63\x63\x65ptTOSReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\"H\n\x0eSetLocationReq\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\x12\x0e\n\x06radius\x18\x04 \x01(\x01\".\n\x1c\x41\x63\x63\x65ptCommunityGuidelinesReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\x32\xe6\x02\n\x04Jail\x12\x44\n\x08JailInfo\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12N\n\tAcceptTOS\x12\x1f.org.couchers.jail.AcceptTOSReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12R\n\x0bSetLocation\x12!.org.couchers.jail.SetLocationReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12n\n\x19\x41\x63\x63\x65ptCommunityGuidelines\x12/.org.couchers.jail.AcceptCommunityGuidelinesReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x1a\x04\x88\xb5\x18\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_JAILINFORES = _descriptor.Descriptor(
  name='JailInfoRes',
  full_name='org.couchers.jail.JailInfoRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jailed', full_name='org.couchers.jail.JailInfoRes.jailed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_not_accepted_tos', full_name='org.couchers.jail.JailInfoRes.has_not_accepted_tos', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_not_added_location', full_name='org.couchers.jail.JailInfoRes.has_not_added_location', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_not_accepted_community_guidelines', full_name='org.couchers.jail.JailInfoRes.has_not_accepted_community_guidelines', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=220,
)


_ACCEPTTOSREQ = _descriptor.Descriptor(
  name='AcceptTOSReq',
  full_name='org.couchers.jail.AcceptTOSReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accept', full_name='org.couchers.jail.AcceptTOSReq.accept', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=252,
)


_SETLOCATIONREQ = _descriptor.Descriptor(
  name='SetLocationReq',
  full_name='org.couchers.jail.SetLocationReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='city', full_name='org.couchers.jail.SetLocationReq.city', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.jail.SetLocationReq.lat', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.jail.SetLocationReq.lng', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='org.couchers.jail.SetLocationReq.radius', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=326,
)


_ACCEPTCOMMUNITYGUIDELINESREQ = _descriptor.Descriptor(
  name='AcceptCommunityGuidelinesReq',
  full_name='org.couchers.jail.AcceptCommunityGuidelinesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accept', full_name='org.couchers.jail.AcceptCommunityGuidelinesReq.accept', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=374,
)

DESCRIPTOR.message_types_by_name['JailInfoRes'] = _JAILINFORES
DESCRIPTOR.message_types_by_name['AcceptTOSReq'] = _ACCEPTTOSREQ
DESCRIPTOR.message_types_by_name['SetLocationReq'] = _SETLOCATIONREQ
DESCRIPTOR.message_types_by_name['AcceptCommunityGuidelinesReq'] = _ACCEPTCOMMUNITYGUIDELINESREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JailInfoRes = _reflection.GeneratedProtocolMessageType('JailInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _JAILINFORES,
  '__module__' : 'jail_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.jail.JailInfoRes)
  })
_sym_db.RegisterMessage(JailInfoRes)

AcceptTOSReq = _reflection.GeneratedProtocolMessageType('AcceptTOSReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCEPTTOSREQ,
  '__module__' : 'jail_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.jail.AcceptTOSReq)
  })
_sym_db.RegisterMessage(AcceptTOSReq)

SetLocationReq = _reflection.GeneratedProtocolMessageType('SetLocationReq', (_message.Message,), {
  'DESCRIPTOR' : _SETLOCATIONREQ,
  '__module__' : 'jail_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.jail.SetLocationReq)
  })
_sym_db.RegisterMessage(SetLocationReq)

AcceptCommunityGuidelinesReq = _reflection.GeneratedProtocolMessageType('AcceptCommunityGuidelinesReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCEPTCOMMUNITYGUIDELINESREQ,
  '__module__' : 'jail_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.jail.AcceptCommunityGuidelinesReq)
  })
_sym_db.RegisterMessage(AcceptCommunityGuidelinesReq)



_JAIL = _descriptor.ServiceDescriptor(
  name='Jail',
  full_name='org.couchers.jail.Jail',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=377,
  serialized_end=735,
  methods=[
  _descriptor.MethodDescriptor(
    name='JailInfo',
    full_name='org.couchers.jail.Jail.JailInfo',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JAILINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcceptTOS',
    full_name='org.couchers.jail.Jail.AcceptTOS',
    index=1,
    containing_service=None,
    input_type=_ACCEPTTOSREQ,
    output_type=_JAILINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetLocation',
    full_name='org.couchers.jail.Jail.SetLocation',
    index=2,
    containing_service=None,
    input_type=_SETLOCATIONREQ,
    output_type=_JAILINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcceptCommunityGuidelines',
    full_name='org.couchers.jail.Jail.AcceptCommunityGuidelines',
    index=3,
    containing_service=None,
    input_type=_ACCEPTCOMMUNITYGUIDELINESREQ,
    output_type=_JAILINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JAIL)

DESCRIPTOR.services_by_name['Jail'] = _JAIL

# @@protoc_insertion_point(module_scope)
